@@ -133,7 +133,7 @@ gis_page_real_get_builder (GisPage *page)
       return NULL;
     }
 
-  resource_path = g_strdup_printf ("/ui/gis-%s-page.ui", klass->page_id);
+  resource_path = g_strdup_printf ("/org/gnome/initial-setup/gis-%s-page.ui", klass->page_id);
 
   builder = gtk_builder_new ();
   gtk_builder_add_from_resource (builder, resource_path, &error);
@@ -159,6 +159,8 @@ gis_page_constructed (GObject *object)
 
   page->builder = klass->get_builder (page);
 
+  gis_page_locale_changed (page);
+
   G_OBJECT_CLASS (gis_page_parent_class)->constructed (object);
 }
 
@@ -225,3 +227,18 @@ gis_page_set_complete (GisPage *page, gboolean complete)
   page->priv->complete = complete;
   g_object_notify_by_pspec (G_OBJECT (page), obj_props[PROP_COMPLETE]);
 }
+
+GtkWidget *
+gis_page_get_action_widget (GisPage *page)
+{
+  if (GIS_PAGE_GET_CLASS (page)->get_action_widget)
+    return GIS_PAGE_GET_CLASS (page)->get_action_widget (page);
+  return NULL;
+}
+
+void
+gis_page_locale_changed (GisPage *page)
+{
+  if (GIS_PAGE_GET_CLASS (page)->locale_changed)
+    return GIS_PAGE_GET_CLASS (page)->locale_changed (page);
+}
