@@ -34,7 +34,6 @@
 #include <ibus.h>
 #endif
 
-#include "gdm-languages.h"
 #include "gnome-region-panel-input.h"
 
 #define WID(s) GTK_WIDGET(gtk_builder_get_object (builder, s))
@@ -1323,7 +1322,7 @@ input_chooser_new (GtkWindow    *main_window,
 
   builder = gtk_builder_new ();
   gtk_builder_add_from_resource (builder,
-                                 "/ui/gnome-region-panel-input-chooser.ui",
+                                 "/org/gnome/initial-setup/gnome-region-panel-input-chooser.ui",
                                  &error);
 
   if (error)
