@@ -26,6 +26,7 @@
 #define PAGE_ID "network"
 
 #include "config.h"
+#include "network-resources.h"
 #include "gis-network-page.h"
 
 #include <glib/gi18n.h>
@@ -635,7 +636,6 @@ gis_network_page_constructed (GObject *object)
 
   refresh_wireless_list (page);
 
-  gis_page_set_title (GIS_PAGE (page), _("Network"));
   gis_page_set_complete (GIS_PAGE (page), TRUE);
 
  out:
@@ -656,6 +656,12 @@ gis_network_page_dispose (GObject *object)
   G_OBJECT_CLASS (gis_network_page_parent_class)->dispose (object);
 }
 
+static void
+gis_network_page_locale_changed (GisPage *page)
+{
+  gis_page_set_title (GIS_PAGE (page), _("Network"));
+}
+
 static void
 gis_network_page_class_init (GisNetworkPageClass *klass)
 {
@@ -663,6 +669,7 @@ gis_network_page_class_init (GisNetworkPageClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   page_class->page_id = PAGE_ID;
+  page_class->locale_changed = gis_network_page_locale_changed;
   object_class->constructed = gis_network_page_constructed;
   object_class->dispose = gis_network_page_dispose;
 
@@ -672,6 +679,7 @@ gis_network_page_class_init (GisNetworkPageClass *klass)
 static void
 gis_network_page_init (GisNetworkPage *page)
 {
+  g_resources_register (network_get_resource ());
   page->priv = GET_PRIVATE (page);
 }
 
