@@ -26,6 +26,7 @@
 #define PAGE_ID "summary"
 
 #include "config.h"
+#include "summary-resources.h"
 #include "gis-summary-page.h"
 
 #include <glib/gstdio.h>
@@ -216,8 +217,17 @@ done_cb (GtkButton *button, GisSummaryPage *page)
   g_file_set_contents (file, "yes", -1, NULL);
   g_free (file);
 
-  remove_trigger_file (page);
-  log_user_in (page);
+  switch (gis_driver_get_mode (GIS_PAGE (page)->driver))
+    {
+    case GIS_DRIVER_MODE_NEW_USER:
+      log_user_in (page);
+      remove_trigger_file (page);
+      break;
+    case GIS_DRIVER_MODE_EXISTING_USER:
+      g_application_quit (G_APPLICATION (GIS_PAGE (page)->driver));
+    default:
+      break;
+    }
 }
 
 static void
@@ -241,7 +251,6 @@ gis_summary_page_get_builder (GisPage *page)
 
   char *filename = g_build_filename (UIDIR, "summary-distro.ui", NULL);
   GError *error = NULL;
-  const char *resource_path = "/ui/gis-" PAGE_ID "-page.ui";
 
   if (gtk_builder_add_from_file (builder, filename, &error))
     goto out;
@@ -251,12 +260,7 @@ gis_summary_page_get_builder (GisPage *page)
 
   g_clear_error (&error);
 
-  gtk_builder_add_from_resource (builder, resource_path, &error);
-
-  if (error != NULL) {
-    g_warning ("Error while loading %s: %s", resource_path, error->message);
-    exit (1);
-  }
+  builder = GIS_PAGE_CLASS (gis_summary_page_parent_class)->get_builder (page);
 
  out:
   g_free (filename);
@@ -277,12 +281,17 @@ gis_summary_page_constructed (GObject *object)
 
   g_signal_connect (WID("summary-start-button"), "clicked", G_CALLBACK (done_cb), page);
 
-  gis_page_set_title (GIS_PAGE (page), _("Thank You"));
   gis_page_set_complete (GIS_PAGE (page), TRUE);
 
   gtk_widget_show (GTK_WIDGET (page));
 }
 
+static void
+gis_summary_page_locale_changed (GisPage *page)
+{
+  gis_page_set_title (GIS_PAGE (page), _("Thank You"));
+}
+
 static void
 gis_summary_page_class_init (GisSummaryPageClass *klass)
 {
@@ -291,6 +300,7 @@ gis_summary_page_class_init (GisSummaryPageClass *klass)
 
   page_class->page_id = PAGE_ID;
   page_class->get_builder = gis_summary_page_get_builder;
+  page_class->locale_changed = gis_summary_page_locale_changed;
   object_class->constructed = gis_summary_page_constructed;
 
   g_type_class_add_private (object_class, sizeof(GisSummaryPagePrivate));
@@ -299,6 +309,7 @@ gis_summary_page_class_init (GisSummaryPageClass *klass)
 static void
 gis_summary_page_init (GisSummaryPage *page)
 {
+  g_resources_register (summary_get_resource ());
   page->priv = GET_PRIVATE (page);
 }
 
